<?php
/**
 * DeubertIt\ElasticApm
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2020 All rights reserved
 * @package ElasticApm
 */

namespace DeubertIt\ElasticApm;

/**
 * Class Bootstrap
 * @package DeubertIt\ElasticApm\Base
 *
 * @author Karsten Deubert <info@deubert.it>
 */
class Base
{
    const ELASTIC_APM_REGISTRYKEY = 'elastic-apm-agent';

    /**
     * Initialize Elastic APM with configuration and put instance into Zend_Registry
     *
     * configuration:
     *
     * appName       : Name of this application, Required
     * appVersion    : Application version, Default: ''
     * serverUrl     : APM Server Endpoint, Default: 'http://127.0.0.1:8200'
     * secretToken   : Secret token for APM Server, Default: null
     * hostname      : Hostname to transmit to the APM Server, Default: gethostname()
     * active        : Activate the APM Agent, Default: true
     * timeout       : Guzzle Client timeout, Default: 5
     * env           : $_SERVER vars to send to the APM Server, empty set sends all. Keys are case sensitive, Default: ['SERVER_SOFTWARE']
     * cookies       : Cookies to send to the APM Server, empty set sends all. Keys are case sensitive, Default: []
     * httpClient    : Extended GuzzleHttp\Client Default: []
     * backtraceLimit: Depth of a transaction backtrace, Default: unlimited
     *
     * example:
     *
     * $config = [
     *   'appName'     => 'application-name',
     *   'appVersion'  => 'release-name,
     *   'serverUrl'   => 'http://127.0.0.1:8200',
     *   'active'      => $active
     *   'secretToken' => 'asdf1234',
     *   'hostname'    => 'test01',
     *   'env'         => ['DOCUMENT_ROOT', 'REMOTE_ADDR', 'REMOTE_USER', 'APPLICATION_ENV'],
     *   'cookies'     => ['my-cookie'],
     *   'httpClient'  => [
     *     'verify' => false,
     *     'proxy'  => 'tcp://localhost:8125'
     *   ],
     * ];
     *
     * @param array $config
     */
    public static function bootstrap($config)
    {
        $agent = new \PhilKra\Agent($config);

        \Zend_Registry::set(self::ELASTIC_APM_REGISTRYKEY, $agent);
    }

    /**
     * @return \PhilKra\Agent
     * @throws \Exception
     */
    public static function getRegistryInstance()
    {
        if (!\Zend_Registry::isRegistered(self::ELASTIC_APM_REGISTRYKEY))
        {
            throw new \Exception('no client found or not bootstrapped');
        }

        return \Zend_Registry::get(self::ELASTIC_APM_REGISTRYKEY);
    }
}
